pub trait OrthonormalBasis: Sized {
type Basis;
// Required methods
fn orthonormal_basis(self) -> Self::Basis;
fn orthonormal_vector(self) -> Self;
}Expand description
Trait to compute the orthonormal basis of a vector.
Required Associated Types
Required Methods
Sourcefn orthonormal_basis(self) -> Self::Basis
fn orthonormal_basis(self) -> Self::Basis
Computes the vectors which, when combined with self, form an orthonormal basis.
Sourcefn orthonormal_vector(self) -> Self
fn orthonormal_vector(self) -> Self
Computes a vector orthogonal to self with a unit length (if self has a unit length).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<N: SimdRealCopy + CopySign<N>> OrthonormalBasis for Vector3<N>
Available on non-SPIR-V only.
impl<N: SimdRealCopy + CopySign<N>> OrthonormalBasis for Vector3<N>
Available on non-SPIR-V only.
Sourceimpl<N: SimdRealCopy> OrthonormalBasis for Vector2<N>
Available on non-SPIR-V only.
impl<N: SimdRealCopy> OrthonormalBasis for Vector2<N>
Available on non-SPIR-V only.